.. _config_sample:

====================
Configuration sample
====================

The following is a sample compute-hyperv configuration for adaptation and
use.

The sample configuration can also be viewed in :download:`file form
</_static/compute-hyperv.conf.sample>`.

Config options that are specific to the Hyper-V Nova driver can be found in
the ``[hyperv]`` config group section.

.. important::

   The sample configuration file is auto-generated from compute-hyperv when
   this documentation is built. You must ensure your version of
   compute-hyperv matches the version of this documentation.

.. literalinclude:: /_static/compute-hyperv.conf.sample
